@@ -16,8 +16,6 @@ from .query_params import (
     TablesSortByDB,
     TablesDBSorting,
     TablesIndexSorting,
-    series_sort_mapping,
-    table_sort_mapping,
 )
 from .series_tag import SeriesTagEntity
 from .series_value import SeriesValueEntity
